# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## Unreleased

<small>[Compare with latest](https://github.com/fepegar/uv2conda/compare/v0.1.2...HEAD)</small>

### Added

- Add changelog ([ae06e14](https://github.com/fepegar/uv2conda/commit/ae06e14a55adc8308dc1bedca7a11c0555a2c25a) by Fernando Pérez-García).
- Add justfile ([959ab43](https://github.com/fepegar/uv2conda/commit/959ab439251c653805d0a0ac8b4a94dc668ee592) by Fernando Pérez-García).

<!-- insertion marker -->
## [v0.1.2](https://github.com/fepegar/uv2conda/releases/tag/v0.1.2) - 2024-12-02

<small>[Compare with v0.1.1](https://github.com/fepegar/uv2conda/compare/v0.1.1...v0.1.2)</small>

### Added

- Add CHANGELOG ([d78a5d8](https://github.com/fepegar/uv2conda/commit/d78a5d8545c0a04871e8fb159648426417638235) by Fernando Pérez-García).

### Removed

- Remove background when printing the YAML contents ([8b6ca77](https://github.com/fepegar/uv2conda/commit/8b6ca771f38e4e1ddd953b406b8f0d757363f5ca) by Fernando Pérez-García).
- Remove line wrap in output YAML ([6f9a8df](https://github.com/fepegar/uv2conda/commit/6f9a8df0c36776a5d10eb336f3d2f0729b71490c) by Fernando Pérez-García).

## [v0.1.1](https://github.com/fepegar/uv2conda/releases/tag/v0.1.1) - 2024-11-28

<small>[Compare with first commit](https://github.com/fepegar/uv2conda/compare/a3ae5ef5fc577bf80ccc325fb8127d644d140939...v0.1.1)</small>

### Added

- Add bump-my-version config ([006a4fc](https://github.com/fepegar/uv2conda/commit/006a4fc634b7f6da387174531085fb442595c57f) by Fernando Pérez-García).
- Add version to __init__ ([068629e](https://github.com/fepegar/uv2conda/commit/068629effbfa630edcca2dc878f9e2db298226a2) by Fernando Pérez-García).
- Add project URLs ([ddbcc33](https://github.com/fepegar/uv2conda/commit/ddbcc33eed6e48e312cc5c256d44a987ac87daee) by Fernando Pérez-García).
- Add pre-commit (#2) ([d5d2fa6](https://github.com/fepegar/uv2conda/commit/d5d2fa6e2730fb0005fcb31ab70123e774c40192) by Fernando Pérez-García).
- Add some imports in __init__ ([4a1a012](https://github.com/fepegar/uv2conda/commit/4a1a012de08bc0557486b54369c98076b76a4638) by Fernando Pérez-García).
- Add support to pass extra args to uv ([c6e743e](https://github.com/fepegar/uv2conda/commit/c6e743ea3e798de7214149c2c4dc714d25f880e7) by Fernando Pérez-García).

